==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/de/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Eine Geräte-Anfrage auf der Webseite wurde vom Benutzer abgebrochen',
    'a_user_requested' => 'Ein Benutzer hat ein Gerät auf der Webseite angefordert',
    'accessory_name' => 'Zubehör Name:',
    'additional_notes' => 'Zusätzliche Bemerkungen:',
    'admin_has_created' => 'Ein Administrator hat auf der :web Webseite ein Konto für Sie erstellt.',
    'asset' => 'Asset:',
    'asset_name' => 'Gegenstands Name:',
    'asset_requested' => 'Gegenstand angefordert',
    'asset_tag' => 'Gegenstands Etikett:',
    'assigned_to' => 'Zugewiesen an',
    'best_regards' => 'Grüße,',
    'canceled' => 'Abgebrochen:',
    'checkin_date' => 'Rücknahmedatum:',
    'checkout_date' => 'Herausgabedatum:',
    'click_to_confirm' => 'Bitte klicken Sie zum Bestätigen Ihres :web Kontos auf den folgenden Link:',
    'click_on_the_link_accessory' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Zubehörs zu bestätigen.',
    'click_on_the_link_asset' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Gegenstands zu bestätigen.',
    'Confirm_Asset_Checkin' => 'Asset-Check-in-Bestätigung',
    'Confirm_Accessory_Checkin' => 'Zurücknehmen von Zubehör bestätigen',
    'Confirm_accessory_delivery' => 'Zubehör Herausgabe bestätigen',
    'Confirm_license_delivery' => 'Lizenz Herausgabe bestätigen',
    'Confirm_asset_delivery' => 'Gegenstands Herausgabe bestätigen',
    'Confirm_consumable_delivery' => 'Verbrauchsmaterial Herausgabe bestätigen',
    'current_QTY' => 'Aktuelle Menge',
    'Days' => 'Tage',
    'days' => 'Tage',
    'expecting_checkin_date' => 'Erwartetes Rückgabedatum:',
    'expires' => 'Ablaufdatum',
    'Expiring_Assets_Report' => 'Bericht über ablaufende Gegenstände.',
    'Expiring_Licenses_Report' => 'Bericht über ablaufende Lizenzen.',
    'hello' => 'Hallo',
    'hi' => 'Hallo',
    'i_have_read' => 'Ich habe die Nutzungsbedingungen gelesen und stimme diesen zu, und ich habe diesen Gegenstand erhalten.',
    'item' => 'Gegenstand:',
    'Item_Request_Canceled' => 'Gegenstands Anfrage abgebrochen',
    'Item_Requested' => 'Gegenstand angefortdert',
    'link_to_update_password' => 'Klicken Sie bitte auf den folgenden Link zum Aktualisieren Ihres :web Passworts:',
    'login_first_admin' => 'Melden Sie sich zu Ihrer neuen Snipe-IT-Installation mithilfe der unten stehenden Anmeldeinformationen an:',
    'login' => 'Benutzername:',
    'Low_Inventory_Report' => 'Bericht über niedrige Lagerbestände',
    'min_QTY' => 'Mindestmenge',
    'name' => 'Name',
    'new_item_checked' => 'Ein neuer Gegenstand wurde unter Ihrem Namen ausgecheckt. Details folgen.',
    'password' => 'Passwort:',
    'password_reset' => 'Passwort zurücksetzen',

    'read_the_terms' => 'Bitte lesen Sie die nachfolgenden Nutzungsbedingungen.',
    'read_the_terms_and_click' => 'Bitte lesen Sie die Nutzungsbedingungen und klicken Sie auf den Link unten, um zu bestätigen, dass Sie diese gelesen und die Nutzungsbedingungen und den Gegenstand erhalten haben.',
    'requested' => 'Angefordert:',
    'reset_link' => 'Ihr Link zum Zurücksetzen des Kennworts',
    'reset_password' => 'Klicken Sie hier, um Ihr Passwort zurückzusetzen:',
    'serial' => 'Seriennummer',
    'supplier' => 'Lieferant',
    'tag' => 'Kennzeichnung',
    'test_email' => 'Test E-Mail von Snipe-IT',
    'test_mail_text' => 'Dies ist ein Test von Snipe-IT-Asset-Management-System. Wenn Sie das erhalten haben, funktioniert das Senden von Mails :)',
    'the_following_item' => 'Der folgende Gegenstand wurde eingecheckt: ',
    'low_inventory_alert' => 'Es gibt :count Artikel, der unter dem Minimum ist oder kurz davor ist.|Es gibt :count Artikel, die unter dem Minimum sind oder kurz davor sind.',
    'assets_warrantee_alert' => 'Es gibt :count Asset mit einer auslaufenden Garantie in den nächsten :threshold Tagen.| Es gibt :count Assets mit auslaufenden Garantien in den nächsten :threshold Tagen.',
    'license_expiring_alert' => 'Es gibt :count auslaufende Lizenz in den nächsten :threshold Tagen.|Es gibt :count auslaufende Lizenzen in den nächsten :threshold Tagen.',
    'to_reset' => 'Zum Zurücksetzen Ihres :web Passwortes, füllen Sie bitte dieses Formular aus:',
    'type' => 'Typ',
    'upcoming-audits' => 'Es ist :count Asset vorhanden, für das innerhalb von :threshold Tagen ein Audit durchzuführen ist. |Es gibt :count Assets, für die innerhalb von :threshold Tagen Audits durchzuführen sind.',
    'user' => 'Benutzer',
    'username' => 'Benutzername',
    'welcome' => 'Wilkommen, :name',
    'welcome_to' => 'Willkommen bei :web!',
    'your_credentials' => 'Ihre Snipe-IT Anmeldedaten',
    'Accessory_Checkin_Notification' => 'Zubehör zurückgenommen',
    'Asset_Checkin_Notification' => 'Asset zurückgenommen',
    'License_Checkin_Notification' => 'Lizenz zurückgenommen',
    'Expected_Checkin_Report' => 'Bericht über erwartete Asset Rückgaben',
    'Expected_Checkin_Notification' => 'Erinnerung: :name Rückgabedatum nähert sich',
    'Expected_Checkin_Date' => 'Ihr ausgebuchtes Asset ist fällig zur Rückgabe am :date',
    'your_assets' => 'Ihre Assets anzeigen'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/de/mail.php <==
<?php

return [
    'a_user_canceled' => 'Eine Geräte-Anfrage auf der Webseite wurde vom Benutzer abgebrochen',
    'a_user_requested' => 'Ein Benutzer hat ein Gerät auf der Webseite angefordert',
    'accessory_name' => 'Zubehör Name:',
    'additional_notes' => 'Zusätzliche Bemerkungen:',
    'admin_has_created' => 'Ein Administrator hat auf der :web Webseite ein Konto für Sie erstellt.',
    'asset' => 'Asset:',
    'asset_name' => 'Gegenstands Name:',
    'asset_requested' => 'Gegenstand angefordert',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Zugewiesen an',
    'best_regards' => 'Grüße,',
    'canceled' => 'Abgebrochen:',
    'checkin_date' => 'Rücknahmedatum:',
    'checkout_date' => 'Herausgabedatum:',
    'click_to_confirm' => 'Bitte klicken Sie zum Bestätigen Ihres :web Kontos auf den folgenden Link:',
    'click_on_the_link_accessory' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Zubehörs zu bestätigen.',
    'click_on_the_link_asset' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Gegenstands zu bestätigen.',
    'Confirm_Asset_Checkin' => 'Asset-Check-in-Bestätigung',
    'Confirm_Accessory_Checkin' => 'Zurücknehmen von Zubehör bestätigen',
    'Confirm_accessory_delivery' => 'Zubehör Herausgabe bestätigen',
    'Confirm_license_delivery' => 'Lizenz Herausgabe bestätigen',
    'Confirm_asset_delivery' => 'Bestätigung einer Asset Herausgabe',
    'Confirm_consumable_delivery' => 'Verbrauchsmaterial Herausgabe bestätigen',
    'current_QTY' => 'Aktuelle Menge',
    'Days' => 'Tage',
    'days' => 'Tage',
    'expecting_checkin_date' => 'Erwartetes Rückgabedatum:',
    'expires' => 'Ablaufdatum',
    'Expiring_Assets_Report' => 'Bericht über ablaufende Gegenstände.',
    'Expiring_Licenses_Report' => 'Bericht über ablaufende Lizenzen.',
    'hello' => 'Hallo',
    'hi' => 'Hallo',
    'i_have_read' => 'Ich habe die Nutzungsbedingungen gelesen und stimme diesen zu, und ich habe diesen Gegenstand erhalten.',
    'item' => 'Gegenstand:',
    'Item_Request_Canceled' => 'Gegenstands Anfrage abgebrochen',
    'Item_Requested' => 'Gegenstand angefordert',
    'link_to_update_password' => 'Klicken Sie bitte auf den folgenden Link zum Aktualisieren Ihres :web Passworts:',
    'login_first_admin' => 'Melden Sie sich zu Ihrer neuen Snipe-IT-Installation mithilfe der unten stehenden Anmeldeinformationen an:',
    'login' => 'Benutzername:',
    'Low_Inventory_Report' => 'Bericht über niedrige Lagerbestände',
    'min_QTY' => 'Mindestmenge',
    'name' => 'Name',
    'new_item_checked' => 'Ein neuer Gegenstand wurde unter Ihrem Namen ausgecheckt. Details folgen.',
    'password' => 'Passwort:',
    'password_reset' => 'Passwort zurücksetzen',

    'read_the_terms' => 'Bitte lesen Sie die nachfolgenden Nutzungsbedingungen.',
    'read_the_terms_and_click' => 'Bitte lesen Sie die Nutzungsbedingungen und klicken Sie auf den Link unten, um zu bestätigen, dass Sie diese gelesen und die Nutzungsbedingungen und den Gegenstand erhalten haben.',
    'requested' => 'Angefordert:',
    'reset_link' => 'Ihr Link zum Zurücksetzen des Kennworts',
    'reset_password' => 'Klicken Sie hier, um Ihr Passwort zurückzusetzen:',
    'serial' => 'Seriennummer',
    'supplier' => 'Lieferant',
    'tag' => 'Kennzeichnung',
    'test_email' => 'Test E-Mail von Snipe-IT',
    'test_mail_text' => 'Dies ist ein Test von Snipe-IT-Asset-Management-System. Wenn Sie das erhalten haben, funktioniert das Senden von Mails :)',
    'the_following_item' => 'Der folgende Gegenstand wurde eingecheckt: ',
    'low_inventory_alert' => 'Es gibt :count Artikel, der unter dem Minimum ist oder kurz davor ist.|Es gibt :count Artikel, die unter dem Minimum sind oder kurz davor sind.',
    'assets_warrantee_alert' => 'Die Garantie von :count Asset wird in :threshold Tagen auslaufen.|Die Garantie von :count Assets wird in :threshold Tagen auslaufen.',
    'license_expiring_alert' => 'Es gibt :count auslaufende Lizenz in den nächsten :threshold Tagen.|Es gibt :count auslaufende Lizenzen in den nächsten :threshold Tagen.',
    'to_reset' => 'Zum Zurücksetzen Ihres :web Passwortes, füllen Sie bitte dieses Formular aus:',
    'type' => 'Typ',
    'upcoming-audits' => 'Es ist :count Asset vorhanden, für das innerhalb von :threshold Tagen ein Audit durchzuführen ist. |Es gibt :count Assets, für die innerhalb von :threshold Tagen Audits durchzuführen sind.',
    'user' => 'Benutzer',
    'username' => 'Benutzername',
    'welcome' => 'Wilkommen, :name',
    'welcome_to' => 'Willkommen bei :web!',
    'your_credentials' => 'Ihre Snipe-IT Anmeldedaten',
    'Accessory_Checkin_Notification' => 'Zubehör zurückgenommen',
    'Asset_Checkin_Notification' => 'Asset zurückgenommen',
    'License_Checkin_Notification' => 'Lizenz zurückgenommen',
    'Expected_Checkin_Report' => 'Bericht über erwartete Asset Rückgaben',
    'Expected_Checkin_Notification' => 'Erinnerung: :name Rückgabedatum nähert sich',
    'Expected_Checkin_Date' => 'Ihr ausgebuchtes Asset ist fällig zur Rückgabe am :date',
    'your_assets' => 'Ihre Assets anzeigen',
];
